@@ -99,8 +99,7 @@ public:
   @short main calendar view widget
   @author Cornelius Schumacher
 */
-class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
-    public Akonadi::ETMCalendar::CalendarObserver
+class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Akonadi::ETMCalendar::CalendarObserver
 {
     Q_OBJECT
 public:
@@ -308,11 +307,8 @@ public Q_SLOTS:
       Create new Event from given summary, description, attachment list and
       attendees list
     */
-    void newEvent(const QString &summary,
-                  const QString &description = QString(),
-                  const QStringList &attachment = QStringList(),
-                  const QStringList &attendees = QStringList(),
-                  const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
+    void newEvent(const QString &summary, const QString &description = QString(), const QStringList &attachment = QStringList(),
+                  const QStringList &attendees = QStringList(), const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
     void newFloatingEvent();
 
     /** Create a read-only viewer dialog for the supplied incidence.
@@ -399,11 +395,8 @@ public Q_SLOTS:
     /** create new todo with parent todo */
     void newSubTodo(const Akonadi::Collection &collection);
 
-    void newTodo(const QString &summary,
-                 const QString &description = QString(),
-                 const QStringList &attachments = QStringList(),
-                 const QStringList &attendees = QStringList(),
-                 const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
+    void newTodo(const QString &summary, const QString &description = QString(), const QStringList &attachments = QStringList(),
+                 const QStringList &attendees = QStringList(), const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
 
     void newJournal();
     void newJournal(const QDate &date);
@@ -443,26 +436,19 @@ public Q_SLOTS:
 
     /** passes on the message that an event has changed to the currently
      * activated view so that it can make appropriate display changes. */
-    void changeIncidenceDisplay(const Akonadi::Item &incidence,
+    void changeIncidenceDisplay(const Akonadi::Item & incidence,
                                 Akonadi::IncidenceChanger::ChangeType);
 
-    void slotCreateFinished(int changeId, const Akonadi::Item &item,
-                            Akonadi::IncidenceChanger::ResultCode resultCode,
-                            const QString &errorString);
+    void slotCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
-    void slotModifyFinished(int changeId, const Akonadi::Item &item,
-                            Akonadi::IncidenceChanger::ResultCode resultCode,
-                            const QString &errorString);
+    void slotModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
-    void slotDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &itemIdList,
-                            Akonadi::IncidenceChanger::ResultCode resultCode,
-                            const QString &errorString);
+    void slotDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &itemIdList, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
     void startMultiModify(const QString &text);
     void endMultiModify();
 
-    void updateView(const QDate &start, const QDate &end, const QDate &preferredMonth,
-                    const bool updateTodos = true);
+    void updateView(const QDate &start, const QDate &end, const QDate &preferredMonth, const bool updateTodos = true);
     void updateView() override;
 
     void updateUnmanagedViews();
@@ -684,8 +670,7 @@ private:
 
     void createPrinter();
 
-    void dissociateOccurrence(const Akonadi::Item &incidence, const QDate &,
-                              bool futureOccurrences);
+    void dissociateOccurrence(const Akonadi::Item &incidence, const QDate &, bool futureOccurrences);
 
     /**
      * Returns the default collection.
