@@ -66,7 +66,7 @@ SearchDialog::SearchDialog(CalendarView *calendarview)
 
     // Results list view
     QVBoxLayout *layout = new QVBoxLayout;
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     listView = new EventViews::ListView(m_calendarview->calendar(), this);
     layout->addWidget(listView);
     m_ui->listViewFrame->setLayout(layout);
@@ -170,7 +170,7 @@ void SearchDialog::search(const QRegExp &re)
     if (m_ui->eventsCheck->isChecked()) {
         events
             = m_calendarview->calendar()->events(
-            startDt, endDt, QTimeZone::systemTimeZone(), m_ui->inclusiveCheck->isChecked());
+                  startDt, endDt, QTimeZone::systemTimeZone(), m_ui->inclusiveCheck->isChecked());
     }
 
     KCalCore::Todo::List todos;
