@@ -62,7 +62,7 @@ KOAgendaView::KOAgendaView(QWidget *parent, bool isSideBySide)
     , d(new Private(isSideBySide, this))
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(d->mAgendaView);
 
     connect(d->mAgendaView, &EventViews::AgendaView::zoomViewHorizontally,
@@ -242,8 +242,7 @@ void KOAgendaView::changeIncidenceDisplayAdded(const Akonadi::Item &)
     // Do nothing, EventViews::AgendaView knows when items change
 }
 
-void KOAgendaView::changeIncidenceDisplay(const Akonadi::Item &,
-                                          Akonadi::IncidenceChanger::ChangeType)
+void KOAgendaView::changeIncidenceDisplay(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)
 {
     // Do nothing, EventViews::AgendaView knows when items change
 }
